@@ -390,7 +390,7 @@ wzd_user_t * FCN_GET_USER(uid_t uid)
   /* Now get IP */
   user->ip_allowed[0][0] = '\0';
 
-  snprintf(query, 512, "select UserIP.ip from UserIP,users where users.uid='%d' AND users.ref=UserIP.ref", uid);
+  snprintf(query, 512, "SELECT UserIP.ip FROM UserIP,users WHERE users.uid='%d' AND users.ref=UserIP.ref", uid);
 
   if (mysql_query(&mysql, query) != 0) {
     free(query);
@@ -418,7 +418,7 @@ wzd_user_t * FCN_GET_USER(uid_t uid)
 
   /* Now get Groups */
 
-  snprintf(query, 512, "select groups.gid from groups,users,UGR where users.uid='%d' AND users.ref=UGR.uref AND groups.ref=UGR.gref", uid);
+  snprintf(query, 512, "SELECT groups.gid FROM groups,users,UGR WHERE users.uid='%d' AND users.ref=UGR.uref AND groups.ref=UGR.gref", uid);
 
   if (mysql_query(&mysql, query) != 0) {
     free(query);
@@ -442,6 +442,28 @@ wzd_user_t * FCN_GET_USER(uid_t uid)
   }
   user->group_num = i;
 
+  mysql_free_result(res);
+
+  /* Now get Stats */
+  snprintf(query, 512, "SELECT bytes_ul_total,bytes_dl_total,files_ul_total,files_dl_total FROM Stats,users WHERE users.uid=%d AND users.ref=Stats.ref", uid);
+
+  if (mysql_query(&mysql, query) != 0) {
+    free(query);
+    _wzd_mysql_error(__FILE__, __FUNCTION__, __LINE__);
+    return user;
+  }
+  if (!(res = mysql_store_result(&mysql))) {
+    free(query);
+    _wzd_mysql_error(__FILE__, __FUNCTION__, __LINE__);
+    return user;
+  }
+
+  row = mysql_fetch_row(res);
+
+  wzd_row_get_ullong(&user->stats.bytes_ul_total, row, SCOL_BYTES_UL);
+  wzd_row_get_ullong(&user->stats.bytes_dl_total, row, SCOL_BYTES_DL);
+  wzd_row_get_ulong(&user->stats.files_ul_total, row, SCOL_FILES_UL);
+  wzd_row_get_ulong(&user->stats.files_dl_total, row, SCOL_FILES_DL);
 
   mysql_free_result(res);
 
@@ -508,6 +530,39 @@ wzd_group_t * FCN_GET_GROUP(gid_t gid)
 
   mysql_free_result(res);
 
+  /* Now get IP */
+  group->ip_allowed[0][0] = '\0';
+
+  query = malloc(512);
+  snprintf(query, 512, "SELECT GroupIP.ip FROM GroupIP,groups WHERE groups.gid='%d' AND groups.ref=GroupIP.ref", gid);
+
+  if (mysql_query(&mysql, query) != 0) {
+    free(query);
+    _wzd_mysql_error(__FILE__, __FUNCTION__, __LINE__);
+    return group;
+  }
+  if (!(res = mysql_store_result(&mysql))) {
+    free(query);
+    _wzd_mysql_error(__FILE__, __FUNCTION__, __LINE__);
+    return group;
+  }
+
+  i =0;
+  while ( (row = mysql_fetch_row(res)) ) {
+    if (i >= HARD_IP_PER_GROUP) {
+#ifdef DEBUG
+      fprintf(stderr,"Mysql: too many IP for group %s, dropping others\n",group->groupname);
+#endif
+      break;
+    }
+    wzd_row_get_string(group->ip_allowed[i], MAX_IP_LENGTH, row, 0 /* query asks only one column */);
+    i++;
+  }
+
+
+  mysql_free_result(res);
+  free(query);
+
   return group;
 }
 
@@ -690,6 +745,50 @@ static gid_t * wzd_mysql_get_group_list(void)
   return gid_list;
 }
 
+int _wzd_run_delete_query(char * query, size_t length, const char * query_format, ...)
+{
+  MYSQL_RES   *res;
+  va_list argptr;
+
+  va_start(argptr, query_format);
+  vsnprintf(query, length, query_format, argptr);
+  va_end(argptr);
+
+  if (mysql_query(&mysql, query) != 0) {
+    _wzd_mysql_error(__FILE__, __FUNCTION__, __LINE__);
+    return -1;
+  }
+
+  res = mysql_store_result(&mysql);
+
+  if (res) mysql_free_result(res);
+
+
+  return 0;
+}
+
+int _wzd_run_insert_query(char * query, size_t length, const char * query_format, ...)
+{
+  MYSQL_RES   *res;
+  va_list argptr;
+
+  va_start(argptr, query_format);
+  vsnprintf(query, length, query_format, argptr);
+  va_end(argptr);
+
+  if (mysql_query(&mysql, query) != 0) {
+    _wzd_mysql_error(__FILE__, __FUNCTION__, __LINE__);
+    return -1;
+  }
+
+  res = mysql_store_result(&mysql);
+
+  if (res) mysql_free_result(res);
+
+
+  return 0;
+}
+
 int _wzd_run_update_query(char * query, size_t length, const char * query_format, ...)
 {
   MYSQL_RES   *res;
@@ -700,7 +799,6 @@ int _wzd_run_update_query(char * query, size_t length, const char * query_format
   va_end(argptr);
 
   if (mysql_query(&mysql, query) != 0) {
-    free(query);
     _wzd_mysql_error(__FILE__, __FUNCTION__, __LINE__);
     return -1;
   }
@@ -732,8 +830,8 @@ int wzd_backend_init(wzd_backend_t * backend)
   backend->backend_find_user = FCN_FIND_USER;
   backend->backend_find_group = FCN_FIND_GROUP;
 
-  backend->backend_mod_user = FCN_MOD_USER;
-  backend->backend_mod_group = FCN_MOD_GROUP;
+  backend->backend_mod_user = wmysql_mod_user;
+  backend->backend_mod_group = wmysql_mod_group;
 
   backend->backend_chpass = NULL;
   backend->backend_commit_changes = FCN_COMMIT_CHANGES;
