@@ -71,6 +71,7 @@
 #include "wzd_misc.h"
 #include "wzd_log.h"
 #include "wzd_tls.h"
+#include "wzd_fs.h"
 #include "wzd_init.h"
 #include "wzd_ip.h"
 #include "wzd_libmain.h"
@@ -986,12 +987,12 @@ int server_switch_to_config(wzd_config_t *config)
 
   /** \todo XXX FIXME open log dir */
   if (config->logdir) {
-    struct statbuf s;
-    if (fs_stat(config->logdir,&s)) {
+    fs_filestat_t s;
+    if (fs_file_stat(config->logdir,&s)) {
       out_err(LEVEL_HIGH,"Could not open log dir (%s)\n", config->logdir);
       return 1;
     }
-    if (!S_ISDIR(s.st_mode)) {
+    if (!S_ISDIR(s.mode)) {
       out_err(LEVEL_HIGH,"Log dir (%s) is NOT a directory, I'm confused!\n", config->logdir);
       return 1;
     }
@@ -1316,8 +1317,7 @@ static void free_config(wzd_config_t * config)
     closelog();
 #endif
   }
-  if (mainConfig->logfile)
-    log_close();
+  log_fini();
   if (mainConfig->logfilename)
     wzd_free(mainConfig->logfilename);
   if (mainConfig->config_filename)
@@ -1416,12 +1416,14 @@ void serverMainThreadExit(int retcode)
   chtbl_destroy((CHTBL*)mainConfig->htab);
   wzd_free(mainConfig->htab);
 
-  wzd_debug_fini();
-
   /* free(mainConfig); */
   unlink(mainConfig->pid_file);
   free_config(mainConfig);
+  mainConfig = NULL;
   server_mutex_set_fini();
+
+  wzd_debug_fini();
+
 #if defined(_MSC_VER)
   WSACleanup();
 #endif
