@@ -122,9 +122,9 @@ typedef enum {
   TOK_SITE_READD,
   TOK_SITE_RELOAD,
   TOK_SITE_REOPEN,
-  TOK_SITE_RULES,
   TOK_SITE_RUSAGE,
   TOK_SITE_SAVECFG,
+  TOK_SITE_SECTIONS,
   TOK_SITE_SHUTDOWN,
   TOK_SITE_SWHO,
   TOK_SITE_SU,
