@@ -213,6 +213,7 @@ int data_execute(wzd_context_t * context, wzd_user_t * user, fd_set *fdr, fd_set
       context->current_action.bytesnow = 0;
       context->state = STATE_COMMAND;
       data_close(context);
+
 /*      limiter_free(context->current_limiter);
       context->current_limiter = NULL;*/
 
@@ -231,6 +232,9 @@ int data_execute(wzd_context_t * context, wzd_user_t * user, fd_set *fdr, fd_set
 out_err(LEVEL_INFO,"Send 226 message returned %d\n",ret);
 #endif
 
+      /* user will be invalidated */
+      backend_mod_user(mainConfig->backend.name, user->username, user, _USER_BYTESDL | _USER_CREDITS);
+
       context->current_action.token = TOK_UNKNOWN;
       context->idle_time_start = server_time;
     }
@@ -289,6 +293,9 @@ out_err(LEVEL_INFO,"Send 226 message returned %d\n",ret);
       out_err(LEVEL_INFO,"Send 226 message returned %d\n",ret);
 #endif
 
+      /* user will be invalidated */
+      backend_mod_user(mainConfig->backend.name, user->username, user, _USER_BYTESUL | _USER_CREDITS);
+
       context->current_action.token = TOK_UNKNOWN;
       context->idle_time_start = server_time;
     }
