@@ -52,6 +52,7 @@
 
 #include "wzd_structs.h"
 
+#include "wzd_fs.h"
 #include "wzd_log.h"
 #include "wzd_misc.h"
 #include "wzd_messages.h"
@@ -123,8 +124,8 @@ int do_site_grpadd(wzd_string_t *ignored, wzd_string_t *command_line, wzd_contex
   }
   /* check if homedir exist */
   {
-    struct statbuf s;
-    if (fs_stat(homedir,&s) || !S_ISDIR(s.st_mode)) {
+    fs_filestat_t s;
+    if (fs_file_stat(homedir,&s) || !S_ISDIR(s.mode)) {
       ret = send_message_with_args(501,context,"Homedir does not exist");
       str_deallocate(groupname);
       return 0;
@@ -503,7 +504,7 @@ int do_site_grpdelip(wzd_string_t *ignored, wzd_string_t *command_line, wzd_cont
   /* try to take argument as a slot number */
   ul = strtoul(str_tochar(ip),&ptr,0);
   if (*ptr=='\0') {
-    if (ul <= 0 || ul >= HARD_IP_PER_GROUP) {
+    if (ul <= 0 || ul > HARD_IP_PER_GROUP) {
       ret = send_message_with_args(501,context,"Invalid ip slot number");
       str_deallocate(ip);
       return 0;
@@ -735,8 +736,8 @@ int do_site_grpchange(wzd_string_t *ignored, wzd_string_t *command_line, wzd_con
   else if (strcmp(str_tochar(field),"homedir")==0) {
     /* check if homedir exist */
     {
-      struct statbuf s;
-      if (fs_stat(str_tochar(value),&s) || !S_ISDIR(s.st_mode)) {
+      fs_filestat_t s;
+      if (fs_file_stat(str_tochar(value),&s) || !S_ISDIR(s.mode)) {
         ret = send_message_with_args(501,context,"Homedir does not exist");
         str_deallocate(groupname); str_deallocate(field); str_deallocate(value);
         return 0;
