@@ -39,6 +39,10 @@
 # include <stdint.h>
 #endif
 
+#ifdef HAVE_INTTYPES_H
+# include <inttypes.h>
+#endif
+
 
 #if defined(_MSC_VER)
 
@@ -59,6 +63,10 @@
 #define i32_t __int32
 #define i16_t __int16
 
+#define __PRI64_PREFIX  "I64"
+
+#define PRIu64  __PRI64_PREFIX "u"
+
 typedef unsigned fd_t;
 
 typedef size_t ssize_t;
@@ -217,7 +225,7 @@ typedef size_t ssize_t;
 /*********************** VERSION **************************/
 
 /* Version */
-#define  WZD_VERSION_NUM "0.5.2 visual"
+#define  WZD_VERSION_NUM "0.5.3 visual"
 #define  WZD_BUILD_NUM __DATE__
 #define  WZD_BUILD_OPTS  "visual"
 
