@@ -52,6 +52,7 @@
 #include "wzd_vfs.h"
 #include "wzd_dir.h"
 #include "wzd_file.h"
+#include "wzd_fs.h"
 #include "wzd_log.h"
 #include "wzd_misc.h"
 
@@ -123,7 +124,7 @@ int vfs_free(wzd_vfs_t **vfs_list)
 int vfs_add_restricted(wzd_vfs_t ** vfs_list, const char *vpath, const char *path, const char *target)
 {
   wzd_vfs_t * current_vfs, * new_vfs;
-  struct statbuf s;
+  fs_filestat_t s;
 
   current_vfs = *vfs_list;
   while (current_vfs)
@@ -136,7 +137,7 @@ int vfs_add_restricted(wzd_vfs_t ** vfs_list, const char *vpath, const char *pat
     current_vfs = current_vfs->next_vfs;
   }
 
-  if (fs_stat(path,&s)) {
+  if (fs_file_stat(path,&s)) {
     /* destination does not exist */
     return 1;
   }
@@ -594,7 +595,7 @@ int checkpath_new(const char *wanted_path, char *path, wzd_context_t *context)
   char * ptr_ftppath;
   wzd_user_t * user;
   unsigned int sys_offset;
-  struct statbuf s;
+  fs_filestat_t s;
   struct wzd_file_t * perm_list, * entry;
 
   user = GetUserByID(context->userid);
@@ -681,7 +682,7 @@ int checkpath_new(const char *wanted_path, char *path, wzd_context_t *context)
     strcpy(syspath+sys_offset, lpart);
 
     /** \todo check permissions here */
-    if (fs_lstat(syspath,&s)) {
+    if (fs_file_lstat(syspath,&s)) {
       /* file/dir does not exist
        * 3 cases: error, vfs, symlink */
 
@@ -753,7 +754,7 @@ int checkpath_new(const char *wanted_path, char *path, wzd_context_t *context)
       } /* check for vfs entries */
 
       /* even if found, check the new destination exists */
-      if (ret || fs_lstat(syspath,&s)) { /* this time, it is really not found */
+      if (ret || fs_file_lstat(syspath,&s)) { /* this time, it is really not found */
         if (!rpart || *rpart=='\0') {
           /* we return the 'what it would have been' path anyway, so it can be used */
           strcpy(syspath+sys_offset, lpart);
@@ -777,7 +778,7 @@ int checkpath_new(const char *wanted_path, char *path, wzd_context_t *context)
      *   - symlink (on filesystem)
      *   - file
      */
-    if (S_ISDIR(s.st_mode) || S_ISLNK(s.st_mode)) {
+    if (S_ISDIR(s.mode) || S_ISLNK(s.mode)) {
       if (syspath[sys_offset-1] != '/')
         syspath[sys_offset++] = '/';
       if (_checkFileForPerm(syspath,".",RIGHT_CWD,user)) {
